// ChatServer.java
//
// Informatics 45 Spring 2010
// Code Example: A Simple Socket Client and Server
//
// This is the program that acts as the server.  It differs slightly from
// the client, though a lot of the same ideas permeate it, especially once
// the two sides are connected.
//
// (If you haven't read the code and comments for the client yet, you should
// do that now.  I've explained some things in the client code that I'm not
// explaining here, to avoid explaining it twice.)

package inf45.spring2010.socket1;

import java.io.IOException;
import java.io.PrintWriter;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.Scanner;


public class ChatServer
{
	public static void main(String[] args)
	throws IOException
	{
		Scanner consoleIn = new Scanner(System.in);

		// We don't ask the user what address they'd like to connect to; we
		// only ask them for a port.  In particular, we're asking them for the
		// port that they'd like to listen on.  Listening just means sitting
		// and waiting for someone to connect to the server's address on the
		// same port.  When someone connects on that port, a socket is created
		// and the conversation can proceed.
		
		System.out.print("Listen port: ");
		int port = Integer.parseInt(consoleIn.nextLine());

		// A ServerSocket implements this concept of "listening."  We tell it
		// what port to listen on when we create it.

		ServerSocket serverSocket = new ServerSocket(port);
		
		System.out.println("Waiting for connection...");

		// We call accept() when we want the program to stop until a connection
		// is made.  So, at this point, the server sits and waits until a
		// client connects.

		Socket socket = serverSocket.accept();

		// Once accept() returns a Socket, there is a connection and the
		// conversation can proceed.  The remaining code in this program is
		// very similar to the client: the difference is that the server
		// doesn't speak first.
		
		System.out.println("Connection accepted!");
		
		Scanner socketIn = new Scanner(socket.getInputStream());
		PrintWriter socketOut = new PrintWriter(socket.getOutputStream(), true);
		
		while (true)
		{
			String message = socketIn.nextLine();

			if (message.length() == 0)
			{
				System.out.println("Client ended conversation");
				break;
			}
			else
			{
				System.out.println("Message: " + message);
			}
			
			System.out.print("Response: ");
			String response = consoleIn.nextLine();

			if (response.length() == 0)
			{
				System.out.println("Ending conversation");
				socketOut.println("");
				break;
			}
			
			socketOut.println(response);
		}

		System.out.println("Closing connection");
		socket.close();
	}
}
